PyCSEP: Tools for Earthquake Forecast Developers
================================================

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Getting Started

    getting_started/installing
    getting_started/core_concepts

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Tutorials and Examples

    tutorials/catalog_filtering.rst
    tutorials/plot_gridded_forecast.rst
    tutorials/gridded_forecast_evaluation.rst
    tutorials/working_with_catalog_forecasts.rst
    tutorials/catalog_forecast_evaluation.rst

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: User Guide

    concepts/catalogs
    concepts/forecasts
    concepts/evaluations
    concepts/regions

.. toctree::
    :maxdepth: 2
    :hidden:
    :caption: Help & Reference

    reference/glossary
    reference/publications
    reference/roadmap
    reference/changelog
    reference/developer_notes
    reference/api_reference


*PyCSEP tools help earthquake forecast model developers evaluate their forecasts and provide the machinery to implement
experiments within CSEP testing centers.*

About
-----
The Collaboratory for the Study of Earthquake Predictability (CSEP) supports an international effort to conduct earthquake
forecasting experiments. CSEP supports these activities by developing the cyberinfrastructure necessary to run earthquake
forecasting experiments including the statistical framework required to evaluate probabilistic earthquake forecasts.

PyCSEP is a python library that provides tools for (1) evaluating probabilistic earthquake forecasts, (2) working
with earthquake catalogs in this context, and (3) creating visualizations. Official experiments that run in CSEP testing centers
will be implemented using the code provided by this package.

Project Goals
-------------
1. Help modelers become familiar with formats, procedures, and evaluations used in CSEP Testing Centers.
2. Provide vetted software for model developers to use in their research.
3. Provide quantitative and visual tools to assess earthquake forecast quality.
4. Promote open-science ideas by ensuring transparency and availability of scientific code and results.
5. Curate benchmark models and data sets for modelers to conduct retrospective experiments of their forecasts.

Contributing
------------
We highly encourage users of this package to get involved in the development process. Any contribution is helpful, even
suggestions on how to improve the package, or additions to the documentation (those are particularly welcome!). Check out
the `Contribution guidelines <https://github.com/SCECCode/csep2/blob/dev/CONTRIBUTING.md>`_ for a step by step on how to contribute to the project. If there are
any questions, please contact us!

Contacting Us
-------------
* For general discussion and bug reports please post issues on the `PyCSEP GitHub <https://github.com/SCECCode/csep2>`_.
* This project adheres to a `Code of Conduct <https://github.com/SCECCode/csep2/blob/dev/CODE_OF_CONDUCT.md>`_. By participating you agree to follow its terms.

List of Contributors
--------------------
* (Lead) William Savran ``wsavran [at] usc [dot] edu``
* Muhammad Asim Khawaja
* Thomas Beutin
* Pablo Iturrieta




